%% Plots of moments along plates radius of austenitic steel
%% Ji Vensk
%% 2019
clc
clear all
%% Constants of the system
miu = 0.27;
E = 193000; %% in MPa
F = 230; %% in N
r1 = linspace (0,1.25,1000);
r= linspace (1.25,4,1000);
r_1 = 1.25;
r_2 = 4; %% in mm
h = 0.5; %% in mm
pmax3 = F/(pi*r_1^2);
B = (E*h^3)/(12*(1-miu^2));

%% Integration constants for FIXED SUPPORT
Z = [1 -1 2*(1-miu)/(r_1^2*(1+miu)); -1 1 2/r_1^2; 0 r_2^2/2 1];
b5 = [-((3+miu)*pmax3*r_1^2)/((1+miu)*8*B)-(pmax3*r_1^2*(miu-1))/(4*B*(1+miu))+pmax3*r_1^2*log(r_1)/(2*B);
    (pmax3*r_1^2*log(r_2))/(2*B)-(3*pmax3*r_1^2)/(7*B);
    (pmax3*r_1^2*r_2^2)/(8*B)-(pmax3*r_1^2*r_2^2*log(r_2))/(4*B)];                    
C5 = Z\b5;
C_1fxdkonst = C5(1,1);
C_2fxdkonst= 0;
C_3fxdkonst = C5(2,1);
C_4fxdkonst = C5(3,1);

m_r1fxdkonst2 = -((3+miu)*pmax3*r1.^2)/16 - (C_1fxdkonst*B*(1+miu))/2;
m_t1fxdkonst2 = -((1+3*miu)*pmax3*r1.^2)/16 - (C_1fxdkonst*B*(1+miu))/2;
%% Second interval
m_r2fxdkonst = (-C_3fxdkonst*B*(1+miu))/2 + (pmax3*r_1^2*(miu-1))/8-(pmax3*r_1^2*(1+miu)*log(r))/4+(C_4fxdkonst*B*(1-miu))*r.^-2;
m_t2fxdkonst = (-C_3fxdkonst*B*(1+miu))/2 +(pmax3*r_1^2*(1-miu))/8-(pmax3*r_1^2*(1+miu)*log(r))/4+(C_4fxdkonst*B*(miu-1))*r.^-2;

%% Integration constants for PINNED SUPPORT
Z2 = [1 -1 2*(1-miu)/(r_1^2*(1+miu)); -1 1 2/r_1^2; 0 -((1+miu)*r_2^2)/(2*(1-miu)) 1];
b6 = [-((3+miu)*pmax3*r_1^2)/((1+miu)*8*B)-(pmax3*r_1^2*(miu-1))/(4*B*(1+miu))+pmax3*r_1^2*log(r_1)/(2*B);
    (pmax3*r_1^2*log(r_2))/(2*B)-(3*pmax3*r_1^2)/(7*B);
    (pmax3*r_1^2*r_2^2)/(8*B)+(pmax3*r_1^2*r_2^2*(1+miu)*log(r_2))/(4*B*(1-miu))];
C6 = Z2\b6;
C_1pinkonst = C6(1,1);
C_2pinkonst= 0;
C_3pinkonst = C6(2,1);
C_4pinkonst = C6(3,1);

%% Moments in first interval

m_r1pinkonst2 = -((3+miu)*pmax3*r1.^2)/16 - (C_1pinkonst*B*(1+miu))/2;
m_t1pinkonst2 = -((1+3*miu)*pmax3*r1.^2)/16 - (C_1pinkonst*B*(1+miu))/2;
%% Second interval
m_r2pinkonst = (-C_3pinkonst*B*(1+miu))/2 + (pmax3*r_1^2*(miu-1))/8-(pmax3*r_1^2*(1+miu)*log(r))/4+(C_4pinkonst*B*(1-miu))*r.^-2;
m_t2pinkonst = (-C_3pinkonst*B*(1+miu))/2 + (pmax3*r_1^2*(1-miu))/8-(pmax3*r_1^2*(1+miu)*log(r))/4+(C_4pinkonst*B*(miu-1))*r.^-2;

%% Plot settings
subplot(2,2,1);  
plot(r1,m_r1fxdkonst2,'b');
hold on
plot (r,m_r2fxdkonst,'b');
title('Radial moment for fixed support')
xlabel('Radius')
ylabel('Moment')
subplot (2,2,2);
plot (r1,m_t1fxdkonst2,'r');
hold on
plot (r,m_t2fxdkonst,'r');
title('Tangential moment for fixed support')
xlabel('Radius')
ylabel('Moment')
subplot(2,2,3);  
plot(r1,m_r1pinkonst2,'b');
hold on
plot (r,m_r2pinkonst,'b');
title('Radial moment for pinned support')
xlabel('Radius')
ylabel('Moment')
subplot (2,2,4);
plot (r1,m_t1pinkonst2,'r');
hold on
plot (r,m_t2pinkonst,'r');
title('Tangential moment for pinned support')
xlabel('Radius')
ylabel('Moment')
suptitle('Constant distribution');