%% Plots of moments along plates radius of austenitic steel
%% Ji Vensk
%% 2019
clc
clear all
%% Constants of the systems
miu = 0.27;
E = 193000; %% in MPa
F = 230; %% in N
r1 = linspace (0,1.25,1000);
r= linspace (1.25,4,1000);
r_1 = 1.25;
r_2 = 4; %% in mm
h = 0.5; %% in mm
B = (E*h^3)/(12*(1-miu^2));

%% LINEAR DISTRIBUTION 
pmax2 = F/(pi*r_1^2-2*pi*r_1^3/(3*r_2));
A = (-pmax2*r_1^3)/(3*r_2*B)+(pmax2*r_1^2)/(2*B);
%% Intergration constants FOR FIXED SUPPORT 
Y = [1 -1 (1-miu)*2/((1+miu)*r_1^2); -1 1 2/r_1^2; 0 r_2^2/2 1];
b3 = [((4+miu)*2*pmax2*r_1^3)/(45*B*r_2*(1+miu))-(pmax2*r_1^2*(3+miu))/((1+miu)*8*B)+A*log(r_1)-A*(miu-1)/(2*(1+miu));
    (pmax2*r_1^2)/(8*B)-(2*pmax2*r_1^3)/(45*B*r_2)+A/2-A*log(r_1);
    A*r_2^2/4-(A*log(r_2)*r_2^2)/2];            
C3 = Y\b3;
C_1fxd2 = C3(1,1);
C_2fxd2 = 0;
C_3fxd2 = C3(2,1);
C_4fxd2 = C3(3,1);

%% Moments in first interval
m_r1_2 = ((4+miu)*pmax2*r1.^3)/(45*r_2)-(pmax2*(3+miu)*r1.^2)/16-C_1fxd2*B*(1+miu)/2;  
m_t1_2 = ((1+4*miu)*pmax2*r1.^3)/(45*r_2)-(pmax2*(1+3*miu)*r1.^2)/16-C_1fxd2*B*(1+miu)/2;
%% Second interval
m_r2_2 = -((1+miu)*B*C_3fxd2)/2+(B*A*(miu-1))/4-((1+miu)*A*B*log(r))/2+((1-miu)*C_4fxd2*B)*r.^-2;
m_t2_2 = -((1+miu)*B*C_3fxd2)/2+(B*A*(1-miu))/4-((1+miu)*A*B*log(r))/2+((miu-1)*C_4fxd2*B)*r.^-2;

%% Integration constants for PINNED SUPPORT
Y2 = [1 -1 (2*(1-miu))/(r_1^2*(1+miu)); -1 1 2/r_1^2; 0 -((1+miu)*r_2^2)/(2*(1-miu)) 1];
b4 = [((4+miu)*2*pmax2*r_1^3)/(45*B*r_2*(1+miu))-(pmax2*r_1^2*(3+miu))/((1+miu)*8*B)+A*log(r_1)-A*(miu-1)/(2*(1+miu));
    (pmax2*r_1^2)/(8*B)-(2*pmax2*r_1^3)/(45*B*r_2)+A/2-A*log(r_1);
    +A*r_2^2/4+((1+miu)*A*log(r_2)*r_2^2)/(2*(1-miu))];
C4 = Y2\b4;
C_1pin2 = C4(1,1);
C_2pin2 = 0;
C_3pin2 = C4(2,1);
C_4pin2 = C4(3,1);

%% Moments in first interval
m_r1pin2 = ((4+miu)*pmax2*r1.^3)/(45*r_2)-(pmax2*(3+miu)*r1.^2)/16-C_1pin2*B*(1+miu)/2;  
m_t1pin2 = ((1+4*miu)*pmax2*r1.^3)/(45*r_2)-(pmax2*(1+3*miu)*r1.^2)/16-C_1pin2*B*(1+miu)/2;
%% Second interval
m_r2pin2 = -((1+miu)*B*C_3pin2)/2+(B*A*(miu-1))/4-((1+miu)*A*B*log(r))/2+((1-miu)*C_4pin2*B)*r.^-2;
m_t2pin2 = -((1+miu)*B*C_3pin2)/2+(B*A*(1-miu))/4-((1+miu)*A*B*log(r))/2+((miu-1)*C_4pin2*B)*r.^-2;
%% Plot settings
subplot(2,2,1);  
plot(r1,m_r1_2,'b');
hold on
plot (r,m_r2_2,'b');
title('Radial moment for fixed support')
xlabel('Radius')
ylabel('Moment')
subplot (2,2,2);
plot (r1,m_t1_2,'r');
hold on
plot (r,m_t2_2,'r');
title('Tangential moment for fixed support')
xlabel('Radius')
ylabel('Moment')
subplot(2,2,3);  
plot(r1,m_r1pin2,'b');
hold on
plot (r,m_r2pin2,'b');
title('Radial moment for pinned support')
xlabel('Radius')
ylabel('Moment')
subplot (2,2,4);
plot (r1,m_t1pin2,'r');
hold on
plot (r,m_t2pin2,'r');
title('Tangential moment for pinned support')
xlabel('Radius')
ylabel('Moment')
suptitle('Linear distribution');