%% Plots of moments along plates radius of austenitic steel
%% Ji Vensk
%% 2019
clc
clear all
%% Constants of the system
miu = 0.27;
E = 193000; %% in MPa
F = 230; %% in N
r1 = linspace (0,1.25,1000);
r= linspace (1.25,4,1000);
r_1 = 1.25;
r_2 = 4; %% in mm
h = 0.5; %% in mm
B = (E*h^3)/(12*(1-miu^2));

%% PARABOLIC DISTRIBUTION
p_max = (F*2)/(pi*r_1^2); %% in MPa
%% Integration constants FOR FIXED SUPPORT
X=[1 -1 (2*(1-miu))/(r_1^2*(1+miu));-1 1 2/r_1^2;0 r_2^2/2 1];
b = [p_max*r_1^2*log(r_1)/(4*B)-(p_max*r_1^2*(3+miu))/((1+miu)*8*B)+((5+miu)*r_1^2*p_max)/(48*B*(1+miu))-(p_max*r_1^2*(miu-1))/((1+miu)*8*B);
    (11*p_max*r_1^2)/(48*B)-(p_max*r_1^2*log(r_1))/(4*B);
    p_max*r_1^2*r_2^2/(16*B)-p_max*r_1^2*r_2^2*log(r_2)/(8*B)];
C = X\b;
C_1fxd = C(1,1);
C_2fxd = 0;
C_3fxd = C(2,1);
C_4fxd = C(3,1);

%% Moments in first interval
m_r1=(p_max*r1.^4*(5+miu))/(96*r_1^2)+(p_max*r1.^2*(-3-miu))/16 +(C_1fxd*B*(-1-miu))/2;
m_t1=(p_max*r1.^4*(1+5*miu))/(96*r_1^2 )+(p_max*r1.^2*(-1-3*miu))/16+(C_1fxd*B*(-1-miu))/2;

%% Second interval
m_r2 = (p_max*r_1^2*(miu-1))/16+(p_max*r_1^2*log(r)*(-1-miu))/8+(C_4fxd*B*(1-miu))*r.^-2+(C_3fxd*B*(-miu-1))/2;
m_t2 = (p_max*r_1^2*(1-miu))/16+(p_max*r_1^2*log(r)*(-1-miu))/8+(C_4fxd*B*(miu-1))*r.^-2+(C_3fxd*B*(-miu-1))/2;

%% Integration constants FOR PINNED SUPPORT
X2=[1 -1 (2*(1-miu))/(r_1^2*(1+miu));-1 1 2/r_1^2;0 -((1+miu)*r_2^2)/(2*(1-miu)) 1];
b2 =[p_max*r_1^2*log(r_1)/(4*B)-(p_max*r_1^2*(3+miu))/((1+miu)*8*B)+((5+miu)*r_1^2*p_max)/(48*B*(1+miu))-(p_max*r_1^2*(miu-1))/((1+miu)*8*B);
    (11*p_max*r_1^2)/(48*B)-(p_max*r_1^2*log(r_1))/(4*B);
    p_max*r_1^2*r_2^2*(1+miu)*log(r_2)/(8*B*(1-miu))+p_max*r_1^2*r_2^2/(16*B)];
C2 = X2\b2;
C_1pin = C2(1,1);
C_2pin = 0;
C_3pin = C2(2,1);
C_4pin = C2(3,1);

%% Moments in first interval
m_r1pin=(p_max*r1.^4*(5+miu))/(96*r_1^2)+(p_max*r1.^2*(-3-miu))/16 +(C_1pin*B*(-1-miu))/2;
m_t1pin=(p_max*r1.^4*(1+5*miu))/(96*r_1^2 )+(p_max*r1.^2*(-1-3*miu))/16 +(C_1pin*B*(-1-miu))/2;
%% Second interval
m_r2pin = (p_max*r_1^2*(miu-1))/16+(p_max*r_1^2*log(r)*(-1-miu))/8+(C_4pin*B*(1-miu))*r.^-2+(C_3pin*B*(-miu-1))/2;
m_t2pin = (p_max*r_1^2*(1-miu))/16+(p_max*r_1^2*log(r)*(-1-miu))/8+(C_4pin*B*(miu-1))*r.^-2+(C_3pin*B*(-miu-1))/2;
%% Plot settings
subplot(2,2,1);  
plot(r1,m_r1,'b');
hold on
plot (r,m_r2,'b');
title('Radial moment for fixed support')
xlabel('Radius')
ylabel('Moment')
subplot (2,2,2);
plot (r1,m_t1,'r');
hold on
plot (r,m_t2,'r');
title('Tangential moment for fixed support')
xlabel('Radius')
ylabel('Moment')
subplot(2,2,3);  
plot(r1,m_r1pin,'b');
hold on
plot (r,m_r2pin,'b');
title('Radial moment for pinned support')
xlabel('Radius')
ylabel('Moment')
subplot (2,2,4);
plot (r1,m_t1pin,'r');
hold on
plot (r,m_t2pin,'r');
title('Tangential moment for pinned support')
xlabel('Radius')
ylabel('Moment')
suptitle('Parabolic distribution');