%% Calculation of the deflections based on analytical solution - aluminium alloy
%% Ji Vensk
%% 2019
clear all
clc
miu = 0.33;
E = 7e4; %% in MPa
h = 0.5; %% in mm
r_2 = 4; %% in mm
F = 170; %% in N
B = (E*h^3)/(12*(1-miu^2)); %% in N*mm
r_1 = 1.25; %% in mm

%% PARABOLIC DISTRIBUTION
p_max = (F*2)/(pi*r_1^2); %% in MPa
%% Integration constants FOR FIXED SUPPORT
X=[1 -1 (2*(1-miu))/(r_1^2*(1+miu));-1 1 2/r_1^2;0 r_2^2/2 1];
b = [p_max*r_1^2*log(r_1)/(4*B)-(p_max*r_1^2*(3+miu))/((1+miu)*8*B)+((5+miu)*r_1^2*p_max)/(48*B*(1+miu))-(p_max*r_1^2*(miu-1))/((1+miu)*8*B);
    (11*p_max*r_1^2)/(48*B)-(p_max*r_1^2*log(r_1))/(4*B);
    p_max*r_1^2*r_2^2/(16*B)-p_max*r_1^2*r_2^2*log(r_2)/(8*B)];
C = X\b;
C_1fxd = C(1,1);
C_2fxd = 0;
C_3fxd = C(2,1);
C_4fxd = C(3,1);
%% Calculation of the displacement
C_6fxd = (p_max*r_1^2*r_2^2)/(16*B)-(p_max*r_1^2*r_2^2*log(r_2))/(16*B)-(C_3fxd*r_2^2)/4-C_4fxd*log(r_2);
C_5fxd=(p_max*r_1^4)/(6*96*B)-(p_max*r_1^4)/(64*B)-(C_1fxd*r_1^2)/4+(C_3fxd*r_1^2)/4-(p_max*r_1^4)/(16*B)+C_4fxd*log(r_1)+(p_max*r_1^4*log(r_1))/(16*B)+C_6fxd;
w_fxdPARA = C_5fxd;

%% Integration constants FOR PINNED SUPPORT
X2=[1 -1 (2*(1-miu))/(r_1^2*(1+miu));-1 1 2/r_1^2;0 -((1+miu)*r_2^2)/(2*(1-miu)) 1];
b2 =[p_max*r_1^2*log(r_1)/(4*B)-(p_max*r_1^2*(3+miu))/((1+miu)*8*B)+((5+miu)*r_1^2*p_max)/(48*B*(1+miu))-(p_max*r_1^2*(miu-1))/((1+miu)*8*B);
    (11*p_max*r_1^2)/(48*B)-(p_max*r_1^2*log(r_1))/(4*B);
    p_max*r_1^2*r_2^2*(1+miu)*log(r_2)/(8*B*(1-miu))+p_max*r_1^2*r_2^2/(16*B)];
C2 = X2\b2;
C_1pin = C2(1,1);
C_2pin = 0;
C_3pin = C2(2,1);
C_4pin = C2(3,1);
%% Calculation of the displacement
C_6pin = (p_max*r_1^2*r_2^2)/(16*B)-(p_max*r_1^2*r_2^2*log(r_2))/(16*B)-(C_3pin*r_2^2)/4-C_4pin*log(r_2);
C_5pin=(p_max*r_1^4)/(6*96*B)-(p_max*r_1^4)/(64*B)-(C_1pin*r_1^2)/4+(C_3pin*r_1^2)/4-(p_max*r_1^4)/(16*B)+C_4pin*log(r_1)+(p_max*r_1^4*log(r_1))/(16*B)+C_6pin;
w_pinPARA = C_5pin;

%% LINEAR DISTRIBUTION 
pmax2 = F/(pi*r_1^2-2*pi*r_1^3/(3*r_2));
A = (-pmax2*r_1^3)/(3*r_2*B)+(pmax2*r_1^2)/(2*B);
%% Intergration constants FOR FIXED SUPPORT 
Y = [1 -1 (1-miu)*2/((1+miu)*r_1^2); -1 1 2/r_1^2; 0 r_2^2/2 1];
b3 = [((4+miu)*2*pmax2*r_1^3)/(45*B*r_2*(1+miu))-(pmax2*r_1^2*(3+miu))/((1+miu)*8*B)+A*log(r_1)-A*(miu-1)/(2*(1+miu));
    (pmax2*r_1^2)/(8*B)-(2*pmax2*r_1^3)/(45*B*r_2)+A/2-A*log(r_1);
    A*r_2^2/4-(A*log(r_2)*r_2^2)/2];            
C3 = Y\b3;
C_1fxd2 = C3(1,1);
C_2fxd2 = 0;
C_3fxd2 = C3(2,1);
C_4fxd2 = C3(3,1);
%% Calculation of the displacement
C_6fxd2 = (A*r_2^2)/4-(C_3fxd2*r_2^2)/4-C_4fxd2*log(r_2)-(A*r_2^2*log(r_2))/4;
C_5fxd2 = (pmax2*r_1^5)/(225*B*r_2)-(pmax2*r_1^4)/(64*B)-(C_1fxd2*r_1^2)/4+(C_3fxd2*r_1^2)/4-(A*r_1^2)/4+C_4fxd2*log(r_1)+(A*r_1^2*log(r_1))/4+C_6fxd2;
w_fxdLINE = C_5fxd2;

%% Integration constants for PINNED SUPPORT
Y2 = [1 -1 (2*(1-miu))/(r_1^2*(1+miu)); -1 1 2/r_1^2; 0 -((1+miu)*r_2^2)/(2*(1-miu)) 1];
b4 = [((4+miu)*2*pmax2*r_1^3)/(45*B*r_2*(1+miu))-(pmax2*r_1^2*(3+miu))/((1+miu)*8*B)+A*log(r_1)-A*(miu-1)/(2*(1+miu));
    (pmax2*r_1^2)/(8*B)-(2*pmax2*r_1^3)/(45*B*r_2)+A/2-A*log(r_1);
    +A*r_2^2/4+((1+miu)*A*log(r_2)*r_2^2)/(2*(1-miu))];
C4 = Y2\b4;
C_1pin2 = C4(1,1);
C_2pin2 = 0;
C_3pin2 = C4(2,1);
C_4pin2 = C4(3,1);
%% Calculation of the displacement
C_6pin2 = (A*r_2^2)/4-(C_3pin2*r_2^2)/4-C_4pin2*log(r_2)-(A*r_2^2*log(r_2))/4;
C_5pin2 = (pmax2*r_1^5)/(225*B*r_2)-(pmax2*r_1^4)/(64*B)-(C_1pin2*r_1^2)/4+(C_3pin2*r_1^2)/4-(A*r_1^2)/4+C_4pin2*log(r_1)+(A*r_1^2*log(r_1))/4+C_6pin2;
w_pinLINE = C_5pin2;

%% LONE FORCE MODEL
%% Calculation of the displacement FIXED SUPPORT
C_3FORCEfxd = (F*r_2^2)/(8*pi*B)-(F*r_2^2*log(r_2))/(8*B*pi)-(F/(4*pi*B)-(F*log(r_2))/(2*pi*B))*r_2^2/4;
w_FORCEfxd = C_3FORCEfxd+(F*r_1^2*log(r_1))/(8*pi*B)-(F*r_1^2)/(8*pi*B)+r_1^2/4*(F/(4*pi*B)-(F*log(r_2))/(2*pi*B));
%% Calculation of the displacement PINNED SUPPORT
C_3FORCEpin = (F*r_2^2)/(8*pi*B)-(F*r_2^2*log(r_2))/(8*B*pi)-((F*(miu-1))/(4*pi*B*(1+miu))-(F*log(r_2))/(2*pi*B))*r_2^2/4;
w_FORCEpin = C_3FORCEpin+(F*r_1^2*log(r_1))/(8*pi*B)-(F*r_1^2)/(8*pi*B)+r_1^2/4*((F*(miu-1))/(4*pi*B*(1+miu))-(F*log(r_2))/(2*pi*B));

%% CONSTANT PRESSURE MODEL 
pmax3 = F/(pi*r_1^2);
%% Integration constants for FIXED SUPPORT
Z = [1 -1 2*(1-miu)/(r_1^2*(1+miu)); -1 1 2/r_1^2; 0 r_2^2/2 1];
b5 = [-((3+miu)*pmax3*r_1^2)/((1+miu)*8*B)-(pmax3*r_1^2*(miu-1))/(4*B*(1+miu))+pmax3*r_1^2*log(r_1)/(2*B);
    (pmax3*r_1^2*log(r_2))/(2*B)-(3*pmax3*r_1^2)/(7*B);
    (pmax3*r_1^2*r_2^2)/(8*B)-(pmax3*r_1^2*r_2^2*log(r_2))/(4*B)];                    
C5 = Z\b5;
C_1fxdkonst = C5(1,1);
C_2fxdkonst= 0;
C_3fxdkonst = C5(2,1);
C_4fxdkonst = C5(3,1);
%% Calculation of the displacement
C_6fxdkonst = (pmax3*r_1^2*r_2^2)/(8*B)-(C_3fxdkonst*r_2^2)/4-(pmax3*r_1^2*r_2^2*log(r_2))/(8*B)-C_4fxdkonst*log(r_2);
C_5fxdkonst = (C_3fxdkonst*r_1^2)/4-(pmax3*r_1^4)/(8*B)+(pmax3*r_1^4*log(r_1))/(8*B)+C_4fxdkonst*log(r_1)-(pmax3*r_1^4)/(64*B)-(C_1fxdkonst*r_1^2)/4+C_6fxdkonst;
w_fxdCONST = C_5fxdkonst;

%% Integration constants for PINNED SUPPORT
Z2 = [1 -1 2*(1-miu)/(r_1^2*(1+miu)); -1 1 2/r_1^2; 0 -((1+miu)*r_2^2)/(2*(1-miu)) 1];
b6 = [-((3+miu)*pmax3*r_1^2)/((1+miu)*8*B)-(pmax3*r_1^2*(miu-1))/(4*B*(1+miu))+pmax3*r_1^2*log(r_1)/(2*B);
    (pmax3*r_1^2*log(r_2))/(2*B)-(3*pmax3*r_1^2)/(7*B);
    (pmax3*r_1^2*r_2^2)/(8*B)+(pmax3*r_1^2*r_2^2*(1+miu)*log(r_2))/(4*B*(1-miu))];
C6 = Z2\b6;
C_1pinkonst = C6(1,1);
C_2pinkonst= 0;
C_3pinkonst = C6(2,1);
C_4pinkonst = C6(3,1);
%% Calculation of the displacement
C_6pinkonst = (pmax3*r_1^2*r_2^2)/(8*B)-(C_3pinkonst*r_2^2)/4-(pmax3*r_1^2*r_2^2*log(r_2))/(8*B)-C_4pinkonst*log(r_2);
C_5pinkonst = (C_3pinkonst*r_1^2)/4-(pmax3*r_1^4)/(8*B)+(pmax3*r_1^4*log(r_1))/(8*B)+C_4pinkonst*log(r_1)-(pmax3*r_1^4)/(64*B)-(C_1pinkonst*r_1^2)/4+C_6pinkonst;
w_pinCONST = C_5pinkonst;

%% OUTPUTS of computed models
fprintf('Below are the critical displacements according to analytical solution (aluminium alloy):\n\n')
fprintf ('Lone force model yield stress in fixed support:   		              %.4f mm\n', w_FORCEfxd)
fprintf ('Lone force model yield stress in pinned support: 		              %.4f mm\n', w_FORCEpin)
fprintf ('Constant pressure distribution model yield stress in fixed support:   %.4f mm\n', w_fxdCONST)
fprintf ('Constant pressure distribution model yield stress in pinned support:  %.4f mm\n', w_pinCONST)
fprintf ('Parabolic pressure distribution model yield stress in fixed support:  %.4f mm\n', w_fxdPARA)
fprintf ('Parabolic pressure distribution model yield stress in pinned support: %.4f mm\n', w_pinPARA)
fprintf ('Linear pressure distribution model yield stress in fixed support:     %.4f mm\n', w_fxdLINE)
fprintf ('Linear pressure distribution model yield stress in pinned support:    %.4f mm\n', w_pinLINE)

